<?php
/**
 * Set the content width based on the theme's design and stylesheet.
 */
 
//Content width 
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}

//Body class
add_filter('body_class','pvs_body_class');
function pvs_body_class( $classes ) {

	foreach ( $classes as $key => $value ) {
		unset($classes[$key]);
	}

	$classes[] = 'home';
	$classes[] = 'blog';
	$classes[] = 'woocommerce-active';

	return $classes;
}

//Js scripts
function pvs_theme_js_scripts() {
	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pvs_theme_js_scripts' );


//The theme supports:
add_theme_support( 'menus' );
add_theme_support( 'automatic-feed-links' );
add_theme_support( 'title-tag' );
add_theme_support( 'post-thumbnails' );
add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
add_theme_support( 'post-formats', array(
		'aside'
	) );


//Disable top admin panel
add_filter('show_admin_bar', '__return_false');


//Widgets
function pvs_widgets(){
	register_sidebar( array(
		'name'          => __( 'Footer area 1', 'pvs-asbab' ),
		'id'            => 'sidebar-footer-area-1',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="footer %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="title__line--2">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 2', 'pvs-asbab' ),
		'id'            => 'sidebar-footer-area-2',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="footer %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="title__line--2">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 3', 'pvs-asbab' ),
		'id'            => 'sidebar-footer-area-3',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="footer %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="title__line--2">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer area 4', 'pvs-asbab' ),
		'id'            => 'sidebar-footer-area-4',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="footer %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="title__line--2">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'pvs_widgets' );
//End. Widgets

//Menu
register_nav_menus( array(
	'asbabmenu' => __( 'Asbab Menu', 'pvs-asbab' )
) );

function pvs_asbab_menu() {
	get_template_part('menu');
}




//Theme header/footer for internal pages
$pvs_theme_header = '<div class="container second_page">' ;
$pvs_theme_footer = '</div>';




//Customize
function pvs_asbab_customize($wp_customize) {

	//Logo
    $wp_customize->add_section(
        'pvs_asbab_logo',
        array(
            'title' => 'Logo',
            'description' => '',
            'priority' => 1,
        )
    );
	
	$wp_customize->add_setting( 
    	'logo', 
    	array(
			'default' => get_template_directory_uri() . '/images/logo.png',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'logo',
			array(
				'label' => 'Logo',
				'section' => 'pvs_asbab_logo',
				'settings' => 'logo'
			)
		)
	);
	

	//End. Logo
	
	//Slideshow
	$wp_customize->add_section(
        'pvs_asbab_slideshow',
        array(
            'title' => 'Homepage Slideshow',
            'description' => '',
            'priority' => 2,
        )
    );
    
    $wp_customize->add_setting(
		'hide_slideshow'
	);
	
	$wp_customize->add_control(
		'hide_slideshow',
		array(
			'label' => 'Hide Slideshow',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'checkbox',
		)
	);
    
    //Slide 1
    $wp_customize->add_setting( 
    	'slider1_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slider/fornt-img/1.jpg',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider1_upload',
			array(
				'label' => 'Slide 1 Upload',
				'section' => 'pvs_asbab_slideshow',
				'settings' => 'slider1_upload'
			)
		)
	);
    
    $wp_customize->add_setting(
		'slider1_title',
		array(
			'default' => 'Stock photos',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_title',
		array(
			'label' => 'Slide 1 Title',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_description',
		array(
			'default' => 'Sell online',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_description',
		array(
			'label' => 'Slide 1 Description',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_button_text',
		array(
			'default' => 'Browse catalog',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_button_text',
		array(
			'label' => 'Slide 1 Button text',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider1_button_link',
		array(
			'default' => site_url() . '/index.php?search=',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider1_button_link',
		array(
			'label' => 'Slide 1 Button link',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	//End. Slide 1
	
	//Slide 2
	$wp_customize->add_setting( 
    	'slider2_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/slider/fornt-img/2.jpg',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'slider2_upload',
			array(
				'label' => 'Slide 2 Upload',
				'section' => 'pvs_asbab_slideshow',
				'settings' => 'slider2_upload'
			)
		)
	);
    
    $wp_customize->add_setting(
		'slider2_title',
		array(
			'default' => 'Prints and Canvas',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_title',
		array(
			'label' => 'Slide 2 Title',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider2_description',
		array(
			'default' => 'Sell online',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_description',
		array(
			'label' => 'Slide 2 Description',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider2_button_text',
		array(
			'default' => 'Shop Now',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_button_text',
		array(
			'label' => 'Slide 2 Button text',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'slider2_button_link',
		array(
			'default' => site_url() . '/index.php?sphoto=1',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'slider2_button_link',
		array(
			'label' => 'Slide 2 Button link',
			'section' => 'pvs_asbab_slideshow',
			'type' => 'text',
		)
	);
	//End. Slide 2

	//End. Slideshow
	
	

	
	
	//Latest images
	$wp_customize->add_section(
        'pvs_asbab_latest_images',
        array(
            'title' => 'Homepage Latest images',
            'description' => '',
            'priority' => 4,
        )
    );
    
    $wp_customize->add_setting(
		'hide_latest_images'
	);
	
	$wp_customize->add_control(
		'hide_latest_images',
		array(
			'label' => 'Hide latest images',
			'section' => 'pvs_asbab_latest_images',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'latest_images_title',
		array(
			'default' => 'Latest Images',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'latest_images_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_asbab_latest_images',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'latest_images_description',
		array(
			'default' => 'New photos',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'latest_images_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_asbab_latest_images',
			'type' => 'text',
		)
	);
	

	
	//End. latest images
	
	
	//Homepage about
    $wp_customize->add_section(
        'pvs_asbab_about',
        array(
            'title' => 'Homepage About Us',
            'description' => '',
            'priority' => 5,
        )
    );
    
    $wp_customize->add_setting(
		'hide_about'
	);
	
	$wp_customize->add_control(
		'hide_about',
		array(
			'label' => 'Hide About Us',
			'section' => 'pvs_asbab_about',
			'type' => 'checkbox',
		)
	);
    
    $wp_customize->add_setting(
		'about_title',
		array(
			'default' => 'Signup as photographer',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'about_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_asbab_about',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'about_description',
		array(
			'default' => 'Upload images and earn commission',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'about_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_asbab_about',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting( 
    	'about_upload', 
    	array(
			'default' => get_template_directory_uri() . '/assets/images/banner/big-img/1.jpg',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
    );
 
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'about_upload',
			array(
				'label' => 'Upload',
				'section' => 'pvs_asbab_about',
				'settings' => 'about_upload'
			)
		)
	);
	
	$wp_customize->add_setting(
		'about_button_text',
		array(
			'default' => 'Signup',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'about_button_text',
		array(
			'label' => 'Button text',
			'section' => 'pvs_asbab_about',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'about_button_link',
		array(
			'default' => site_url() . '/signup/',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'about_button_link',
		array(
			'label' => 'Button link',
			'section' => 'pvs_asbab_about',
			'type' => 'text',
		)
	);	
    
	//End. Homepage about
	
	
	//Featured images
	$wp_customize->add_section(
        'pvs_asbab_featured_images',
        array(
            'title' => 'Homepage Featured images',
            'description' => '',
            'priority' => 6,
        )
    );
    
    $wp_customize->add_setting(
		'hide_featured_images'
	);
	
	$wp_customize->add_control(
		'hide_featured_images',
		array(
			'label' => 'Hide featured images',
			'section' => 'pvs_asbab_featured_images',
			'type' => 'checkbox',
		)
	);
	
	$wp_customize->add_setting(
		'featured_images_title',
		array(
			'default' => 'Featured Images',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'featured_images_title',
		array(
			'label' => 'Title',
			'section' => 'pvs_asbab_featured_images',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'featured_images_description',
		array(
			'default' => 'Exclusive content',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'featured_images_description',
		array(
			'label' => 'Description',
			'section' => 'pvs_asbab_featured_images',
			'type' => 'text',
		)
	);
	
	
	//End. Featured images



	//brands
	$wp_customize->add_section(
        'pvs_asbab_brands',
        array(
            'title' => 'Homepage brands',
            'description' => '',
            'priority' => 6,
        )
    );
    
    $wp_customize->add_setting(
		'hide_brands'
	);
	
	$wp_customize->add_control(
		'hide_brands',
		array(
			'label' => 'Hide brands',
			'section' => 'pvs_asbab_brands',
			'type' => 'checkbox',
		)
	);
	

	
	//End. brands

	
	
	//Footer
    $wp_customize->add_section(
        'pvs_asbab_footer',
        array(
            'title' => 'Footer',
            'description' => '',
            'priority' => 7,
        )
    );
	
    $wp_customize->add_setting(
		'footer_title',
		array(
			'default' => 'Photo Store',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_title',
		array(
			'label' => 'Footer title',
			'section' => 'pvs_asbab_footer',
			'type' => 'text',
		)
	);	
    
    $wp_customize->add_setting(
		'footer_text',
		array(
			'default' => 'Professional software for photographers and video producers.',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_text',
		array(
			'label' => 'Footer text',
			'section' => 'pvs_asbab_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_year',
		array(
			'default' => '2021',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_year',
		array(
			'label' => 'Year',
			'section' => 'pvs_asbab_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_text',
		array(
			'default' => 'Free themes Cloud',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_text',
		array(
			'label' => 'Copyright',
			'section' => 'pvs_asbab_footer',
			'type' => 'text',
		)
	);
	
	$wp_customize->add_setting(
		'footer_copyright_link',
		array(
			'default' => 'https://freethemescloud.com/',
			'sanitize_callback' => 'pvs_asbab_sanitize_text'
		)
	);
	
	$wp_customize->add_control(
		'footer_copyright_link',
		array(
			'label' => 'Copyright Link',
			'section' => 'pvs_asbab_footer',
			'type' => 'text',
		)
	);
	//End. Footer
}

add_action('customize_register', 'pvs_asbab_customize' );

function pvs_asbab_sanitize_text( $input ) {
    return wp_kses_post( force_balance_tags( $input ) );
}
//End. Customize
 
//PVS content
if ( function_exists ( 'pvs_content' ) ) {
	pvs_content();
	
	//Remove unnecessary js scripts and css
	add_action( 'wp_print_scripts', 'pvs_remove_scripts');
	add_action( 'wp_print_styles', 'pvs_remove_styles');

	function pvs_remove_scripts() {
		wp_dequeue_script( 'jquery' );
		wp_deregister_script( 'jquery' );
		
		wp_dequeue_script( 'pvs_jquery' );
		wp_deregister_script( 'pvs_jquery' );
		
		wp_dequeue_script( 'pvs_jqueryui' );
		wp_deregister_script( 'pvs_jqueryui' );
		
		wp_dequeue_script( 'bootstrap' );
		wp_deregister_script( 'bootstrap' );
		
		wp_dequeue_script( 'pvs_jshttprequest' );
		wp_deregister_script( 'pvs_jshttprequest' );
		
		wp_dequeue_script( 'pvs_custom_js' );
		wp_deregister_script( 'pvs_custom_js' );
	}
		
	function pvs_remove_styles() {
		wp_dequeue_style( 'pvs_css' );
		wp_deregister_style( 'pvs_css' );
		
		wp_dequeue_style( 'bootstrap_style' );
		wp_deregister_style( 'bootstrap_style' );
	}

	//Menu asbab
	function pvs_build_menu_categories_asbab($t_id) {
		global $db;
		global $dr;
		$dp = new TMySQLQuery;
		$dp->connection = $db;
		global $itg;
		global $nlimit;
		
		$nn  = 0;
		
		$sql = "select id, id_parent, title, priority, published, url from " . PVS_DB_PREFIX . "category where id_parent=" . $t_id . " and published=1 and activation_date < " . pvs_get_time() . " and (expiration_date > " . pvs_get_time() . " or expiration_date = 0) order by priority, title";
		$dp->open($sql);
		if (!$dp->eof) {
			while (!$dp->eof) {
				$title = pvs_category_url($dp->row["id"], $dp->row["url"]);
				
				$zp  = false;
				
				$sql = "select id, id_parent, title, priority, published, url from " . PVS_DB_PREFIX . "category where id_parent=" . $dp->row["id"] . " and published=1 and activation_date < " . pvs_get_time() . " and (expiration_date > " . pvs_get_time() . " or expiration_date = 0) order by priority, title";
				$dr->open($sql);
				if (!$dr->eof) {
				$zp = true;
				}
				
				if ($nlimit < 10000) {
					$translate_results = pvs_translate_category($dp->row["id"], $dp->row["title"], "", "");
					
					$ttl = addslashes($translate_results["title"]);
					
					if ($nn == 0) {
						$itg .= "<ul  class='sub-menu'>\n";
					}
					
					$class_dropdown  = "";
					
					if ($zp) {
						$class_dropdown = ' class="menu-item menu-item-has-children"';
					}
					
					$itg .= "<li " . $class_dropdown . "><a href=\"" . pvs_category_url($dp->row["id"], $dp->row["url"]) . "\" title=\"" . $ttl . "\">" . $ttl . "</a>\n";
					
					if (!$zp) {
						$itg .= "</li>";
					}
					pvs_build_menu_categories_asbab($dp->row["id"]);
					if ($zp) {
						$itg .= "</li>";
					}
				}
				$nlimit++;
				$nn++;
				$dp->movenext();
			}
			$itg .= "</ul>\n";
		}
	}
	
	$itg="";
	$nlimit=0;
	pvs_build_menu_categories_asbab(0);
	$pvs_theme_content[ 'box_categories' ] = $itg;
}


?>